==> benchling_sdk-0.9.1a0-py3-none-any.whl: benchling_api_client/models/entry_schema_detailed.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.entry_schema_detailed_archive_record import EntrySchemaDetailedArchiveRecord
from ..models.entry_schema_detailed_organization import EntrySchemaDetailedOrganization
from ..models.entry_schema_detailed_type import EntrySchemaDetailedType
from ..models.schema_field import SchemaField
from ..types import UNSET, Unset

T = TypeVar("T", bound="EntrySchemaDetailed")


@attr.s(auto_attribs=True)
class EntrySchemaDetailed:
    """  """

    id: str
    archive_record: Union[Unset, None, EntrySchemaDetailedArchiveRecord] = UNSET
    field_definitions: Union[Unset, List[SchemaField]] = UNSET
    name: Union[Unset, str] = UNSET
    organization: Union[Unset, EntrySchemaDetailedOrganization] = UNSET
    prefix: Union[Unset, str] = UNSET
    registry_id: Union[Unset, str] = UNSET
    type: Union[Unset, EntrySchemaDetailedType] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        archive_record: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.archive_record, Unset):
            archive_record = self.archive_record.to_dict() if self.archive_record else None

        field_definitions: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.field_definitions, Unset):
            field_definitions = []
            for field_definitions_item_data in self.field_definitions:
                field_definitions_item = field_definitions_item_data.to_dict()

                field_definitions.append(field_definitions_item)

        name = self.name
        organization: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        prefix = self.prefix
        registry_id = self.registry_id
        type: Union[Unset, int] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "id": id,
            }
        )
        if archive_record is not UNSET:
            field_dict["archiveRecord"] = archive_record
        if field_definitions is not UNSET:
            field_dict["fieldDefinitions"] = field_definitions
        if name is not UNSET:
            field_dict["name"] = name
        if organization is not UNSET:
            field_dict["organization"] = organization
        if prefix is not UNSET:
            field_dict["prefix"] = prefix
        if registry_id is not UNSET:
            field_dict["registryId"] = registry_id
        if type is not UNSET:
            field_dict["type"] = type

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        archive_record = None
        _archive_record = d.pop("archiveRecord", UNSET)
        if _archive_record is not None and not isinstance(_archive_record, Unset):
            archive_record = EntrySchemaDetailedArchiveRecord.from_dict(_archive_record)

        field_definitions = []
        _field_definitions = d.pop("fieldDefinitions", UNSET)
        for field_definitions_item_data in _field_definitions or []:
            field_definitions_item = SchemaField.from_dict(field_definitions_item_data)

            field_definitions.append(field_definitions_item)

        name = d.pop("name", UNSET)

        organization: Union[Unset, EntrySchemaDetailedOrganization] = UNSET
        _organization = d.pop("organization", UNSET)
        if not isinstance(_organization, Unset):
            organization = EntrySchemaDetailedOrganization.from_dict(_organization)

        prefix = d.pop("prefix", UNSET)

        registry_id = d.pop("registryId", UNSET)

        type = None
        _type = d.pop("type", UNSET)
        if _type is not None and _type is not UNSET:
            type = EntrySchemaDetailedType(_type)

        entry_schema_detailed = cls(
            id=id,
            archive_record=archive_record,
            field_definitions=field_definitions,
            name=name,
            organization=organization,
            prefix=prefix,
            registry_id=registry_id,
            type=type,
        )

        return entry_schema_detailed

==> benchling_sdk-0.9.2a0-py3-none-any.whl: benchling_api_client/models/entry_schema_detailed.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.archive_record import ArchiveRecord
from ..models.entry_schema_detailed_organization import EntrySchemaDetailedOrganization
from ..models.entry_schema_detailed_type import EntrySchemaDetailedType
from ..models.schema_field import SchemaField
from ..types import UNSET, Unset

T = TypeVar("T", bound="EntrySchemaDetailed")


@attr.s(auto_attribs=True)
class EntrySchemaDetailed:
    """  """

    id: str
    archive_record: Union[Unset, None, ArchiveRecord] = UNSET
    field_definitions: Union[Unset, List[SchemaField]] = UNSET
    name: Union[Unset, str] = UNSET
    organization: Union[Unset, EntrySchemaDetailedOrganization] = UNSET
    prefix: Union[Unset, str] = UNSET
    registry_id: Union[Unset, str] = UNSET
    type: Union[Unset, EntrySchemaDetailedType] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        archive_record: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.archive_record, Unset):
            archive_record = self.archive_record.to_dict() if self.archive_record else None

        field_definitions: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.field_definitions, Unset):
            field_definitions = []
            for field_definitions_item_data in self.field_definitions:
                field_definitions_item = field_definitions_item_data.to_dict()

                field_definitions.append(field_definitions_item)

        name = self.name
        organization: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        prefix = self.prefix
        registry_id = self.registry_id
        type: Union[Unset, int] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "id": id,
            }
        )
        if archive_record is not UNSET:
            field_dict["archiveRecord"] = archive_record
        if field_definitions is not UNSET:
            field_dict["fieldDefinitions"] = field_definitions
        if name is not UNSET:
            field_dict["name"] = name
        if organization is not UNSET:
            field_dict["organization"] = organization
        if prefix is not UNSET:
            field_dict["prefix"] = prefix
        if registry_id is not UNSET:
            field_dict["registryId"] = registry_id
        if type is not UNSET:
            field_dict["type"] = type

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        archive_record = None
        _archive_record = d.pop("archiveRecord", UNSET)
        if _archive_record is not None and not isinstance(_archive_record, Unset):
            archive_record = ArchiveRecord.from_dict(_archive_record)

        field_definitions = []
        _field_definitions = d.pop("fieldDefinitions", UNSET)
        for field_definitions_item_data in _field_definitions or []:
            field_definitions_item = SchemaField.from_dict(field_definitions_item_data)

            field_definitions.append(field_definitions_item)

        name = d.pop("name", UNSET)

        organization: Union[Unset, EntrySchemaDetailedOrganization] = UNSET
        _organization = d.pop("organization", UNSET)
        if not isinstance(_organization, Unset):
            organization = EntrySchemaDetailedOrganization.from_dict(_organization)

        prefix = d.pop("prefix", UNSET)

        registry_id = d.pop("registryId", UNSET)

        type = None
        _type = d.pop("type", UNSET)
        if _type is not None and _type is not UNSET:
            type = EntrySchemaDetailedType(_type)

        entry_schema_detailed = cls(
            id=id,
            archive_record=archive_record,
            field_definitions=field_definitions,
            name=name,
            organization=organization,
            prefix=prefix,
            registry_id=registry_id,
            type=type,
        )

        return entry_schema_detailed
